@@ -69,6 +69,8 @@
 #include "gtkdebug.h"
 #include "gtkalias.h"
 
+#include "gdk/gdkprivate.h" /* for GDK_WINDOW_DESTROYED */
+
 /* Private type definitions
  */
 typedef struct _GtkInitFunction		 GtkInitFunction;
@@ -1254,7 +1256,7 @@ gtk_main_do_event (GdkEvent *event)
    *  in the user_data field of GdkWindow's.
    *  Ignore the event if we don't have a widget for it, except
    *  for GDK_PROPERTY_NOTIFY events which are handled specialy.
-   *  Though this happens rarely, bogus events can occour
+   *  Though this happens rarely, bogus events can occur
    *  for e.g. destroyed GdkWindows. 
    */
   event_widget = gtk_get_event_widget (event);
@@ -2041,7 +2043,8 @@ gtk_get_event_widget (GdkEvent *event)
   GtkWidget *widget;
 
   widget = NULL;
-  if (event && event->any.window)
+  if (event && event->any.window && 
+      (event->type == GDK_DESTROY || !GDK_WINDOW_DESTROYED (event->any.window)))
     gdk_window_get_user_data (event->any.window, (void**) &widget);
   
   return widget;
