@@ -24,9 +24,12 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include <config.h>
 #include "gtkviewport.h"
 #include "gtkintl.h"
 #include "gtkmarshalers.h"
+#include "gtkprivate.h"
+#include "gtkalias.h"
 
 enum {
   PROP_0,
@@ -134,7 +137,7 @@ gtk_viewport_class_init (GtkViewportClass *class)
 							P_("Horizontal adjustment"),
 							P_("The GtkAdjustment that determines the values of the horizontal position for this viewport"),
                                                         GTK_TYPE_ADJUSTMENT,
-                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+                                                        GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
   g_object_class_install_property (gobject_class,
                                    PROP_VADJUSTMENT,
@@ -142,16 +145,16 @@ gtk_viewport_class_init (GtkViewportClass *class)
 							P_("Vertical adjustment"),
 							P_("The GtkAdjustment that determines the values of the vertical position for this viewport"),
                                                         GTK_TYPE_ADJUSTMENT,
-                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+                                                        GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
   g_object_class_install_property (gobject_class,
                                    PROP_SHADOW_TYPE,
-                                   g_param_spec_enum ("shadow_type",
+                                   g_param_spec_enum ("shadow-type",
 						      P_("Shadow type"),
 						      P_("Determines how the shadowed box around the viewport is drawn"),
 						      GTK_TYPE_SHADOW_TYPE,
 						      GTK_SHADOW_IN,
-						      G_PARAM_READWRITE));
+						      GTK_PARAM_READWRITE));
 
   widget_class->set_scroll_adjustments_signal =
     g_signal_new ("set_scroll_adjustments",
@@ -461,7 +464,8 @@ viewport_set_adjustment (GtkViewport    *viewport,
   if (!adjustment)
     adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 0.0,
 						     0.0, 0.0, 0.0));
-
+  if (*adjustmentp)
+    g_object_unref (*adjustmentp);
   *adjustmentp = adjustment;
   g_object_ref (adjustment);
   gtk_object_sink (GTK_OBJECT (adjustment));
@@ -555,7 +559,7 @@ gtk_viewport_set_shadow_type (GtkViewport   *viewport,
 	  gtk_widget_queue_draw (GTK_WIDGET (viewport));
 	}
 
-      g_object_notify (G_OBJECT (viewport), "shadow_type");
+      g_object_notify (G_OBJECT (viewport), "shadow-type");
     }
 }
 
@@ -623,6 +627,8 @@ gtk_viewport_realize (GtkWidget *widget)
   viewport->view_window = gdk_window_new (widget->window, &attributes, attributes_mask);
   gdk_window_set_user_data (viewport->view_window, viewport);
 
+  gdk_window_set_back_pixmap (viewport->view_window, NULL, FALSE);
+  
   attributes.x = - hadjustment->value;
   attributes.y = - vadjustment->value;
   attributes.width = hadjustment->upper;
@@ -877,3 +883,6 @@ gtk_viewport_style_set (GtkWidget *widget,
 	gtk_style_set_background (widget->style, widget->window, widget->state);
      }
 }
+
+#define __GTK_VIEWPORT_C__
+#include "gtkaliasdef.c"
